@@ -2,8 +2,9 @@ package Data::Turtle;
 our $AUTHORITY = 'cpan:GENE';
 
 use Moo;
+use POSIX qw( ceil );
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use constant K => 3.14159265358979323846 / 180;
 
@@ -107,15 +108,15 @@ sub left {
 
 sub position {
     my $self = shift;
-    return int($self->x), int($self->y);
+    return ceil($self->x), ceil($self->y);
 }
 
 
 sub get_state {
     my $self = shift;
     return
-        int($self->x),
-        int($self->y),
+        ceil($self->x),
+        ceil($self->y),
         $self->heading,
         $self->pen_status,
         $self->pen_color,
@@ -150,8 +151,8 @@ sub forward {
 
     if ( $self->pen_status == 1 ) {
         return
-            int($xo), int($yo),
-            int($self->x), int($self->y),
+            ceil($xo), ceil($yo),
+            ceil($self->x), ceil($self->y),
             $self->pen_color, $self->pen_size;
     }
 }
@@ -182,8 +183,8 @@ sub goto {
 
     if ( $self->pen_status == 1 ) {
         return
-            int($xo), int($yo),
-            int($self->x), int($self->y),
+            ceil($xo), ceil($yo),
+            ceil($self->x), ceil($self->y),
             $self->pen_color, $self->pen_size;
     }
 }
@@ -202,7 +203,7 @@ Data::Turtle
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -211,18 +212,17 @@ version 0.0101
   $turtle->pen_up;
   $turtle->turn(45);
   $turtle->forward(10);
+  $turtle->goto( 100, 100 );
+  $turtle->mirror;
+  $turtle->backward(10);
   $turtle->pen_down;
+  my ( $x, $y, $heading, $pen_status, $pen_color, $pen_size ) = $turtle->get_state;
+  $turtle->set_state( $x, $y, $heading, $pen_status, $pen_color, $pen_size );
   for my $i ( 1 .. 4 ) {
       my @line = $turtle->forward(50);
       # If there is a line, draw it...
       $turtle->right(90);
   }
-  $turtle->pen_up;
-  $turtle->goto( 10, 10 );
-  $turtle->mirror;
-  $turtle->backward(10);
-  my ( $x, $y, $heading, $pen_status, $pen_color, $pen_size ) = $turtle->get_state;
-  $turtle->set_state( $x, $y, $heading, $pen_status, $pen_color, $pen_size );
 
 =head1 DESCRIPTION
 
